pybedtools.bedtool.BedTool
==========================

.. currentmodule:: pybedtools.bedtool

.. autoclass:: BedTool

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BedTool.__init__
      ~BedTool.absolute_distance
      ~BedTool.all_hits
      ~BedTool.annotate
      ~BedTool.any_hits
      ~BedTool.as_intervalfile
      ~BedTool.at
      ~BedTool.bam_to_bed
      ~BedTool.bam_to_fastq
      ~BedTool.bed6
      ~BedTool.bedpe_to_bam
      ~BedTool.bgzip
      ~BedTool.cat
      ~BedTool.check_genome
      ~BedTool.closest
      ~BedTool.cluster
      ~BedTool.colormap_normalize
      ~BedTool.complement
      ~BedTool.count
      ~BedTool.count_hits
      ~BedTool.coverage
      ~BedTool.cut
      ~BedTool.delete_temporary_history
      ~BedTool.each
      ~BedTool.expand
      ~BedTool.features
      ~BedTool.field_count
      ~BedTool.filter
      ~BedTool.fisher
      ~BedTool.flank
      ~BedTool.from_dataframe
      ~BedTool.genome_coverage
      ~BedTool.groupby
      ~BedTool.handle_kwargs
      ~BedTool.head
      ~BedTool.igv
      ~BedTool.intersect
      ~BedTool.introns
      ~BedTool.jaccard
      ~BedTool.liftover
      ~BedTool.links
      ~BedTool.map
      ~BedTool.mask_fasta
      ~BedTool.merge
      ~BedTool.moveto
      ~BedTool.multi_bam_coverage
      ~BedTool.multi_intersect
      ~BedTool.nucleotide_content
      ~BedTool.overlap
      ~BedTool.pair_to_bed
      ~BedTool.pair_to_pair
      ~BedTool.parallel_apply
      ~BedTool.print_sequence
      ~BedTool.random
      ~BedTool.random_jaccard
      ~BedTool.random_op
      ~BedTool.random_subset
      ~BedTool.randomintersection
      ~BedTool.randomintersection_bp
      ~BedTool.randomstats
      ~BedTool.relative_distance
      ~BedTool.reldist
      ~BedTool.remove_invalid
      ~BedTool.sample
      ~BedTool.save_seqs
      ~BedTool.saveas
      ~BedTool.seq
      ~BedTool.sequence
      ~BedTool.set_chromsizes
      ~BedTool.shuffle
      ~BedTool.slop
      ~BedTool.sort
      ~BedTool.split
      ~BedTool.subtract
      ~BedTool.tabix
      ~BedTool.tabix_intervals
      ~BedTool.tag_bam
      ~BedTool.tail
      ~BedTool.to_bam
      ~BedTool.to_dataframe
      ~BedTool.total_coverage
      ~BedTool.truncate_to_chrom
      ~BedTool.union_bedgraphs
      ~BedTool.window
      ~BedTool.window_maker
      ~BedTool.with_attrs
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BedTool.TEMPFILES
      ~BedTool.file_type
      ~BedTool.intervals
   
   